mathtools.greatest_power_of_two_less_equal
==========================================

.. autofunction:: abjad.tools.mathtools.greatest_power_of_two_less_equal.greatest_power_of_two_less_equal
   :noindex:
